@@ -1,4 +1,5 @@
 from pathlib import Path
+from typing import Optional
 
 from nonebot import get_driver
 from pydantic import BaseModel, Extra
@@ -10,6 +11,7 @@ class Config(BaseModel, extra=Extra.ignore):
     wordcloud_background_color: str = "black"
     wordcloud_font_path: str = str(Path(__file__).parent / "SourceHanSans.otf")
     wordcloud_stopwords_path: Path = Path(__file__).parent / "stopwords.txt"
+    wordcloud_userdict_path: Optional[Path]
 
 
 global_config = get_driver().config
